.. django_turnit documentation master file, created by
   sphinx-quickstart on Mon Mar  7 10:21:38 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to django_turnit's documentation!
=========================================

Contents:

.. toctree::
   :maxdepth: 2

   README
   django_turnit


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

